@@ -5,10 +5,23 @@ This is a description
 """
 import asyncio
 import typing
-from typing import ClassVar, Dict, Iterable, List, Union, overload
+from typing import ClassVar, Dict, Iterable, Generic, List, TypeVar, Union, overload
 
 from example2 import B
 
+T = TypeVar("T")
+U = TypeVar("U")
+
+software = "sphinx"
+
+code_snippet = """
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+# from future.builtins.disabled import *
+# from builtins import *
+
+print("chunky o'block")
+"""
 
 max_rating: int = 10
 
@@ -43,6 +56,10 @@ def f3(imported: B) -> B:
     ...
 
 
+class MyGeneric(Generic[T, U]):
+    ...
+
+
 @overload
 def overloaded_func(a: float) -> float:
     ...
@@ -139,6 +156,16 @@ class C:
         ...
 
 
+class D(C):
+    class Da:
+        ...
+
+    class DB(Da):
+        ...
+
+    ...
+
+
 async def async_function(wait: bool) -> int:
     """Blah.
 
