@@ -107,3 +107,24 @@ def decorator_okay(func):
 class Bar(Foo):
     def method_okay(self, foo=None, bar=None):
         pass
+
+
+class ClassWithNoInit:
+    pass
+
+
+class One:
+    """One."""
+
+    def __init__(self):
+        """One __init__."""
+        super().__init__()
+
+
+class MultilineOne(One):
+    """This is a naughty summary line
+    that exists on two lines."""
+
+
+class Two(One):
+    """Two."""
